import os, sys
from setuptools import setup


long_description = """\
The sphinx document processor generates HTML that uses more advanced syntax
than the HtmlHelp browser in wxPython and wxWidgets can render.  This program
uses the htmlhelp files generated by sphinx as input and attempts to remove
elements that confuse the wxHtmlHelp system while adding or modifying elements
in an attempt to allow the wxHtmlHelp to render the HTML as closely as
possible to the HTML as viewed by a modern browser.

This package provides a script ``sphinx-wxoptimize`` that is designed to
be integrated into your ``make htmlhelp`` target that will automatically
reprocess the sphinx-generated htmlhelp files and convert them to be better
rendered in the wxPython or wxWidgets wxHtmlHelpController.

Automatic Integration with Sphinx
=================================

In your sphinx Makefile, change the htmlhelp target from::

    htmlhelp:
            $(SPHINXBUILD) -b htmlhelp $(ALLSPHINXOPTS) $(BUILDDIR)/htmlhelp

to::

    htmlhelp:
            $(SPHINXBUILD) -b htmlhelp $(ALLSPHINXOPTS) $(BUILDDIR)/htmlhelp
            sphinx-wxoptimize _build/htmlhelp


Development
===========

Please use http://code.google.com/p/sphinx-wxoptimize/ to report any bugs, add
any feature requests, or check out the subversion source code repository.

"""



setup(name = "sphinx_wxoptimize",
      version = "1.0",
      description = "Convert sphinx-generated htmlhelp files into versions optimized for reading using the wxHtmlHelp browser",
      long_description = long_description,
      keywords = "sphinx, htmlhelp, python, wxwidgets, wxpython, documentation",
      license = "GPL",
      author = "Rob McMullen",
      author_email = "robm@users.sourceforge.net",
      url = "http://pypi.python.org/pypi/sphinx-wxoptimize/",
      scripts = ['sphinx-wxoptimize'],
      
      platforms = 'any',
      classifiers=[
          'Development Status :: 5 - Production/Stable',
          'Intended Audience :: Developers',
          'License :: OSI Approved :: GNU General Public License (GPL)',
          'Programming Language :: Python',
          'Operating System :: OS Independent',
          'Topic :: Software Development :: Documentation',
          'Topic :: Text Processing :: Markup :: HTML',
          ],
      install_requires = ['BeautifulSoup>=3.0'],
      zip_safe = True,
      )
